@@ -1,5 +1,5 @@
 package Zapp;
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 # ABSTRACT: Plan building, job creating web app
 
 #pod =head1 SYNOPSIS
@@ -28,7 +28,7 @@ our $VERSION = '0.004';
 #pod =cut
 
 use v5.28;
-use Mojo::Base 'Mojolicious', -signatures;
+use Mojo::Base 'Yancy', -signatures;
 use Scalar::Util qw( blessed );
 use Yancy::Util qw( load_backend );
 use Mojo::JSON qw( encode_json decode_json );
@@ -59,6 +59,16 @@ sub startup( $self ) {
     $self->plugin( Config => { default => {
         backend => 'sqlite:' . $self->home->child( 'zapp.db' ),
         minion => { SQLite => 'sqlite:' . $self->home->child( 'zapp.db' ) },
+        schema => {
+            zapp_plan_inputs => {
+                # XXX: Fix read_schema to detect compound primary keys
+                'x-id-field' => [qw( plan_id name )],
+            },
+            zapp_plan_task_parents => {
+                # XXX: Fix read_schema to detect compound primary keys
+                'x-id-field' => [qw( task_id parent_task_id )],
+            },
+        },
     } } );
 
     # XXX: Add migrate() method to Yancy app base class, varying by
@@ -73,6 +83,8 @@ sub startup( $self ) {
         ->from_data( __PACKAGE__, 'migrations.' . lc $db_type . '.sql' )
         ->migrate;
 
+    $self->SUPER::startup;
+
     $self->plugin( Minion => $self->config->{ minion }->%* );
 
     # XXX: Allow additional task namespaces
@@ -86,20 +98,6 @@ sub startup( $self ) {
         $self->minion->add_task( $class, $class );
     }
 
-    $self->plugin( Yancy =>
-        $self->config->%{qw( backend )},
-        schema => {
-            zapp_plan_inputs => {
-                # XXX: Fix read_schema to detect compound primary keys
-                'x-id-field' => [qw( plan_id name )],
-            },
-            zapp_plan_task_parents => {
-                # XXX: Fix read_schema to detect compound primary keys
-                'x-id-field' => [qw( task_id parent_task_id )],
-            },
-        },
-    );
-
     # Add basic types
     my %base_types = (
         string => 'Zapp::Type::Text',
@@ -546,7 +544,7 @@ Zapp - Plan building, job creating web app
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
